@@ -8,11 +8,7 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "./cogl-bitmap.h" */
-GType cogl_bitmap_error_get_type (void) G_GNUC_CONST;
-#define COGL_TYPE_BITMAP_ERROR (cogl_bitmap_error_get_type())
-
-/* enumerations from "./cogl-material-compat.h" */
+/* enumerations from "./deprecated/cogl-material-compat.h" */
 GType cogl_material_filter_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())
 
@@ -25,10 +21,14 @@ GType cogl_material_alpha_func_get_type (void) G_GNUC_CONST;
 GType cogl_material_layer_type_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_MATERIAL_LAYER_TYPE (cogl_material_layer_type_get_type())
 
-/* enumerations from "./cogl-shader.h" */
+/* enumerations from "./deprecated/cogl-shader.h" */
 GType cogl_shader_type_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_SHADER_TYPE (cogl_shader_type_get_type())
 
+/* enumerations from "./cogl-bitmap.h" */
+GType cogl_bitmap_error_get_type (void) G_GNUC_CONST;
+#define COGL_TYPE_BITMAP_ERROR (cogl_bitmap_error_get_type())
+
 /* enumerations from "./cogl-texture.h" */
 GType cogl_texture_error_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_TEXTURE_ERROR (cogl_texture_error_get_type())
@@ -36,6 +36,9 @@ GType cogl_texture_error_get_type (void) G_GNUC_CONST;
 GType cogl_texture_type_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_TEXTURE_TYPE (cogl_texture_type_get_type())
 
+GType cogl_texture_components_get_type (void) G_GNUC_CONST;
+#define COGL_TYPE_TEXTURE_COMPONENTS (cogl_texture_components_get_type())
+
 /* enumerations from "./cogl-types.h" */
 GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())
